#!/usr/bin/env python3
"""
Run script for the Word Document Server.

This script provides a simple way to start the Word Document Server.
"""

from word_document_server.main import run_server

if __name__ == "__main__":
    run_server()
